/// <reference types="node" />
import TypedArray = NodeJS.TypedArray;
/**
 * Writes value to array at the specified offset. The value must be a valid unsigned 8-bit integer.
 * @param array Uint8Array to be written to
 * @param value Number to be written to array.
 * @param offset plus the number of bytes written.
 */
export declare function writeUInt8(array: Uint8Array, value: number, offset: number): void;
/**
 * Writes value to array at the specified offset as big-endian. The value must be a valid unsigned 16-bit integer.
 * @param array Uint8Array to be written to
 * @param value Number to be written to array.
 * @param offset plus the number of bytes written.
 */
export declare function writeUInt16BE(array: Uint8Array, value: number, offset: number): void;
/**
 * Writes value to array at the specified offset as big-endian. The value must be a valid unsigned 32-bit integer.
 * @param array Uint8Array to be written to
 * @param value Number to be written to array.
 * @param offset plus the number of bytes written.
 */
export declare function writeUInt32BE(array: Uint8Array, value: number, offset: number): void;
/**
 * Reads an unsigned, big-endian 16-bit integer from the array at the specified offset.
 * @param array Uint8Array to read
 * @param offset Number of bytes to skip before starting to read. Must satisfy 0 <= offset <= buf.length - 2
 */
export declare function readUInt16BE(array: Uint8Array, offset: number): string;
/**
 * Reads an unsigned, big-endian 16-bit integer from the array at the specified offset.
 * @param array Uint8Array to read
 * @param offset Number of bytes to skip before starting to read. Must satisfy 0 <= offset <= buf.length - 4
 */
export declare function readUInt32BE(array: Uint8Array, offset: number): string;
/**
 * Compares two Uint8Array or ArrayBuffers
 * @param a first array to compare
 * @param b second array to compare
 */
export declare function equal(a: Uint8Array | ArrayBuffer, b: Uint8Array | ArrayBuffer): boolean;
/**
 * Compare two TypedArrays
 * @param a first array to compare
 * @param b second array to compare
 */
export declare function compare(a: TypedArray, b: TypedArray): 1 | -1 | 0;
